@@ -17,7 +17,7 @@
   +----------------------------------------------------------------------+
 */
 
-$VERSION='$Id: memcache.php 310129 2011-04-11 04:44:27Z hradtke $';
+$VERSION='$Id: memcache.php 326707 2012-07-19 19:02:42Z ab $';
 
 define('ADMIN_USERNAME','memcache'); 	// Admin Username
 define('ADMIN_PASSWORD','password');  	// Admin Password
@@ -54,7 +54,7 @@ function get_host_port_from_server($server){
 		return array($server, 0);
 	}
 	else {
-		return values;
+		return $values;
 	}
 }
 
