@@ -17,7 +17,7 @@
   +----------------------------------------------------------------------+
 */
 
-/* $Id: memcache_binary_protocol.c 326387 2012-06-30 17:41:36Z ab $ */
+/* $Id: memcache_binary_protocol.c 329835 2013-03-19 22:39:10Z hradtke $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -225,13 +225,13 @@ static int mmc_request_read_mutate(mmc_t *mmc, mmc_request_t *request TSRMLS_DC)
 	header = (mmc_mutate_response_header_t *)mmc_stream_get(request->io, sizeof(*header) TSRMLS_CC);
 	if (header != NULL) {
 		int result;
-		zval *key, value;
+		zval *key, *value;
 
 		/* convert remembered key to string and unpack value */
 		key = (zval *)mmc_queue_item(&(req->keys), req->command.reqid);
-		
-		INIT_PZVAL(&value);
-		ZVAL_LONG(&value, ntohll(header->value));
+	
+		MAKE_STD_ZVAL(value);
+		ZVAL_LONG(value, ntohll(header->value));
 		
 		if (Z_TYPE_P(key) != IS_STRING) {
 			zval keytmp = *key;
@@ -241,14 +241,14 @@ static int mmc_request_read_mutate(mmc_t *mmc, mmc_request_t *request TSRMLS_DC)
 			convert_to_string(&keytmp);
 
 			result = request->value_handler(
-				Z_STRVAL(keytmp), Z_STRLEN(keytmp), &value, 
+				Z_STRVAL(keytmp), Z_STRLEN(keytmp), value, 
 				req->value.flags, req->value.cas, request->value_handler_param TSRMLS_CC);
 			
 			zval_dtor(&keytmp);
 		}
 		else {
 			result = request->value_handler(
-				Z_STRVAL_P(key), Z_STRLEN_P(key), &value,
+				Z_STRVAL_P(key), Z_STRLEN_P(key), value,
 				req->value.flags, req->value.cas, request->value_handler_param TSRMLS_CC);
 		}
 		
