@@ -17,7 +17,7 @@
   +----------------------------------------------------------------------+
 */
 
-/* $Id: memcache_queue.h 310129 2011-04-11 04:44:27Z hradtke $ */
+/* $Id: memcache_queue.h 326387 2012-06-30 17:41:36Z ab $ */
 
 #ifndef MEMCACHE_QUEUE_H_
 #define MEMCACHE_QUEUE_H_
@@ -37,12 +37,18 @@ typedef struct mmc_queue {
 #define mmc_queue_reset(q) (q)->len = (q)->head = (q)->tail = 0
 #define mmc_queue_item(q, i) ((q)->tail + (i) < (q)->alloc ? (q)->items[(q)->tail + (i)] : (q)->items[(i) - ((q)->alloc - (q)->tail)]) 
 
-inline void mmc_queue_push(mmc_queue_t *, void *);
-inline void *mmc_queue_pop(mmc_queue_t *);
-inline int mmc_queue_contains(mmc_queue_t *, void *);
-inline void mmc_queue_free(mmc_queue_t *);
-inline void mmc_queue_copy(mmc_queue_t *, mmc_queue_t *);
-inline void mmc_queue_remove(mmc_queue_t *, void *);
+#ifdef PHP_WIN32
+#define MMC_QUEUE_INLINE
+#else
+#define MMC_QUEUE_INLINE inline
+#endif
+
+MMC_QUEUE_INLINE void mmc_queue_push(mmc_queue_t *, void *);
+MMC_QUEUE_INLINE void *mmc_queue_pop(mmc_queue_t *);
+MMC_QUEUE_INLINE int mmc_queue_contains(mmc_queue_t *, void *);
+MMC_QUEUE_INLINE void mmc_queue_free(mmc_queue_t *);
+MMC_QUEUE_INLINE void mmc_queue_copy(mmc_queue_t *, mmc_queue_t *);
+MMC_QUEUE_INLINE void mmc_queue_remove(mmc_queue_t *, void *);
 
 #endif /*MEMCACHE_QUEUE_H_*/
 
